==> eclipse-orion-15.0.0S1-macosx.cocoa.x86_64.zip: web/orion/search/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012, 2015 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/
/*eslint-env amd */
define({
	"Find:": "Find:",
	"Find With": "Find With",
	"ReplaceWith:": "ReplaceWith:",
	"Replace With": "Replace with",
	"Show all": "Show all",
	"Wrap search": "Wrap search",
	"Incremental search": "Incremental search",
	"Whole Word": "Whole Word",
	"Regular expression": "Regular expression",
	"Find after replace": "Find after replace",
	"Options": "Options",
	"Find next match": "Find next match",
	"Find previous match": "Find previous match",
	"Next": "Next",
	"Previous": "Previous",
	"Replace": "Replace",
	"Replace...": "Preview",
	"Replace All": "Replace All",
	"Show Replace": "Replace Mode",
	"Hide Replace": "Search Mode",
	"Search ${0}": "Search ${0}",
	"TypeKeyOrWildCard": "Type a keyword or wild card to search in ",
	"Search failed.": "Search failed.",
	"NoMatchFound": "No matches found for ${0}",
	"Searching...": "Searching...",
	"ResourceChanged.": "Resource has been changed by others.",
	"Failed to write file.": "Failed to write file.",
	"Results": "Results",
	"FilesAofBmatchingC": "Files ${0} of ${1} matching \"${2}\"",
	"ReplaceAwithBforCofD": "Replace \"${0}\" with \"${1}\" for files ${2} of ${3}",
	"Location": "Location",
	"Click to compare": "Click to compare",
	"Search again in this folder with \"${0}\"": "Search again in this folder with \"${0}\"",
	"Files replaced": "Files replaced",
	"Status": "Status",
	"matchesReplacedMsg": "${0} out of ${1}  matches replaced.",
	"Replace all matches with...": "Replace all matches with...",
	"Apply Changes": "Replace Selected",
	"Replace all selected matches": "Replace all selected matches",
	"Hide Compare": "Hide Compare",
	"Hide compare view of changes": "Hide compare view of changes",
	"Show Compare": "Show Compare",
	"Show compare view of changes": "Show compare view of changes",
	"Show All": "Show All",
	"Selected Lines": "Selected Lines",
	"Show all the results in one page": "Show all the results in one page",
	"< Previous Page": "< Previous Page",
	"Show previous page of search result": "Show previous page of search result",
	"Next Page >": "Next Page >",
	"Show next page of search result": "Show next page of search result",
	"Next result": "Next result",
	"Previous result": "Previous result",
	"Expand all results": "Expand all results",
	"Collapse all results": "Collapse all results",
	"Writing files...": "Writing files...",
	"Preparing preview...": "Preparing preview...",
	"Replaced File (${0})": "Replaced File (${0})",
	"Original File (${0})": "Original File (${0})",
	"Sort by Name": "Sort by Name",
	"Compare changes": "Compare changes",
	"Search Results": "Search Results",
	"Replace All Matches": "Replace All Matches",
	"No matches": "No matches",
	"Rename": "Rename",
	"Search": "Search",
	"All types": "All types",
	"File type": "File type",
	"All ${0} files": "All ${0} files",
	"${0} is already saved": "${0} is already saved",
	"Type a search term": "Type a search term",
	"Type a replace term": "Type a replace term",
	"Case sensitive": "Case sensitive",
	"File name": "File name",
	"Path name": "Path name",
	"Save": "Save",
	"Type filter text": "Type filter text",
	"Scope Search": "Scoped Search",
	"Open in Search page for this directory": "Open the Search page for this folder.",
	"${0}. Try your search again.": "${0}. Try your search again.",
	"DeleteSearchTrmMsg": "Click or use delete key to delete the search term",
	"${0} matches": "${0} matches",
	"regexOptionOff" : "Regular expressions are off. Click here or use the options to turn them on for replacement",
	"regexOptionOn" : "Regular expressions are on. Click here or use the options to turn them off",
	"Scope": "Find in:",
	"Show previous search terms": "Show previous search terms",
	"Show previous replace terms": "Show previous replace terms",
	"Preview Replace": "Preview Replace",
	"File name patterns (comma-separated)": "File name patterns (comma-separated):",
	"(* = any string, ? = any character)": "(* = any string, ? = any character)",
	"(${0})": "(${0} matches)",
	"singleMatch": "(1 match)",
	"Choose a Folder": "Choose a Folder",
	"Remove from search results": "Remove from search results",
	"^ Edit Search": "^ Edit Search",
	"Preview: " : "Preview: ",
	"fullPath": "Show Full Path",
	"switchFullPath": "Show/hide full path",
	"refsInProject": "${0} references to \'${1}\' in ${2}",
	"refsInWorkspace": "${0} references to \'${1}\' in the workspace",
	"viewByTypes" : "By types",
	"viewByFiles" : "By files",
	"viewByTypesTooltip": "View references grouped by categories",
	"viewByFilesTooltip": "View references grouped by files",
	"hidePerfectMatch": "Hide perfect matches",
	"showPerfectMatch": "Show perfect matches",
	"hideNonMatch": "Hide non-matches",
	"showNonMatch": "Show non-matches",
	"hidePossibleMatch": "Hide possible matches",
	"showPossibleMatch": "Show possible matches",
	"perfectMatch": "Perfect match",
	"notAMatch": "Not a match",
	"couldBeMatch": "Could be a match",
	"Scope All":"All Folders",
	"Scope Project":"Root Folder",
	"Scope Selected":"Current Folder",
	"Scope Other":"Other",
	"Search Label":"Search:",
	"Exclude Files":"Files to exclude (comma-separated):",
	"The following files are excluded from general setting":"The following files are excluded from general setting:",
	"Current Folder Tooltip": "Search in the closest parent folder of the target.",
	"Root Folder Tooltip": "Search in the root folder of the target.",
	"All Folders Tooltip": "Search in all folders of current workspace",
	"Other Folder Tooltip": "Search in a specified folder",
	"File Patterns Box Tooltip": "Search results are limited to the following file patterns",
	"Exclude Files Box Tooltip": "Search skips the following files, or all files of a folder of the name.",
	"To Replace Mode Tooltip": "Switch To Replace Mode",
	"To Search Mode Tooltip": "Switch To Search Mode"
});

==> eclipse-orion-17.0.0S1-macosx.cocoa.x86_64.zip: web/orion/search/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012, 2015 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/
/*eslint-env amd */
define({
	"Find:": "Find:",
	"Find With": "Find with",
	"ReplaceWith:": "ReplaceWith:",
	"Replace With": "Replace with",
	"Show all": "Show all",
	"Wrap search": "Wrap search",
	"Incremental search": "Incremental search",
	"Whole Word": "Whole Word",
	"Regular expression": "Regular expression",
	"Find after replace": "Find after replace",
	"Options": "Options",
	"Find next match": "Find next match",
	"Find previous match": "Find previous match",
	"Next": "Next",
	"Previous": "Previous",
	"Replace": "Replace",
	"Replace...": "Preview",
	"Replace All": "Replace All",
	"Show Replace": "Replace",
	"Hide Replace": "Search Mode",
	"Search ${0}": "Search ${0}",
	"TypeKeyOrWildCard": "Type a keyword or wild card to search in ",
	"Search failed.": "Search failed.",
	"NoMatchFound": "No matches found for ${0}",
	"Searching...": "Searching...",
	"ResourceChanged.": "Resource has been changed by others.",
	"Failed to write file.": "Failed to write file.",
	"Results": "Results",
	"FilesAofBmatchingC": "Files ${0} of ${1} matching \"${2}\"",
	"ReplaceAwithBforCofD": "Replace \"${0}\" with \"${1}\" for files ${2} of ${3}",
	"Location": "Location",
	"Click to compare": "Click to compare",
	"Search again in this folder with \"${0}\"": "Search again in this folder with \"${0}\"",
	"Files replaced": "Files replaced",
	"Status": "Status",
	"matchesReplacedMsg": "${0} out of ${1}  matches replaced.",
	"Replace all matches with...": "Replace all matches with...",
	"Apply Changes": "Replace Selected",
	"Replace all selected matches": "Replace all selected matches",
	"Hide Compare": "Hide Compare",
	"Hide compare view of changes": "Hide compare view of changes",
	"Show Compare": "Show Compare",
	"Show compare view of changes": "Show compare view of changes",
	"Show All": "Show All",
	"Selected Lines": "Selected Lines",
	"Show all the results in one page": "Show all the results in one page",
	"< Previous Page": "< Previous Page",
	"Show previous page of search result": "Show previous page of search result",
	"Next Page >": "Next Page >",
	"Show next page of search result": "Show next page of search result",
	"Next result": "Next result",
	"Previous result": "Previous result",
	"Expand all results": "Expand all results",
	"Collapse all results": "Collapse all results",
	"Writing files...": "Writing files...",
	"Preparing preview...": "Preparing preview...",
	"Replaced File (${0})": "Replaced File (${0})",
	"Original File (${0})": "Original File (${0})",
	"Sort by Name": "Sort by Name",
	"Compare changes": "Compare changes",
	"Search Results": "Search Results",
	"Replace All Matches": "Replace All Matches",
	"No matches": "No matches",
	"Rename": "Rename",
	"Search": "Search",
	"All types": "All types",
	"File type": "File type",
	"All ${0} files": "All ${0} files",
	"${0} is already saved": "${0} is already saved",
	"Type a search term": "Type a search term",
	"Type a replace term": "Type a replace term",
	"Case sensitive": "Case sensitive",
	"File name": "File name",
	"Path name": "Path name",
	"Save": "Save",
	"Type filter text": "Type filter text",
	"Scope Search": "Scoped Search",
	"Open in Search page for this directory": "Open the Search page for this folder.",
	"${0}. Try your search again.": "${0}. Try your search again.",
	"DeleteSearchTrmMsg": "Click or use delete key to delete the search term",
	"${0} matches": "${0} matches",
	"regexOptionOff" : "Regular expressions are off. Click here or use the options to turn them on for replacement",
	"regexOptionOn" : "Regular expressions are on. Click here or use the options to turn them off",
	"Scope": "Find in:",
	"Show previous search terms": "Show previous search terms",
	"Show previous replace terms": "Show previous replace terms",
	"Preview Replace": "Preview Replace",
	"File name patterns (comma-separated)": "File name patterns (comma-separated):",
	"(* = any string, ? = any character)": "(* = any string, ? = any character)",
	"(${0})": "(${0} matches)",
	"singleMatch": "(1 match)",
	"Choose a Folder": "Choose a Folder",
	"Remove from search results": "Remove from search results",
	"^ Edit Search": "^ Edit Search",
	"Preview: " : "Preview: ",
	"fullPath": "Show Full Path",
	"switchFullPath": "Show/hide full path",
	"refsInProject": "${0} references to \'${1}\' in ${2}",
	"refsInWorkspace": "${0} references to \'${1}\' in the workspace",
	"viewByTypes" : "By types",
	"viewByFiles" : "By files",
	"viewByTypesTooltip": "View references grouped by categories",
	"viewByFilesTooltip": "View references grouped by files",
	"hidePerfectMatch": "Hide perfect matches",
	"showPerfectMatch": "Show perfect matches",
	"hideNonMatch": "Hide non-matches",
	"showNonMatch": "Show non-matches",
	"hidePossibleMatch": "Hide possible matches",
	"showPossibleMatch": "Show possible matches",
	"perfectMatch": "Perfect match",
	"notAMatch": "Not a match",
	"couldBeMatch": "Could be a match",
	"Scope All":"All Folders",
	"Scope Project":"Root Folder",
	"Scope Selected":"Current Folder",
	"Scope Other":"Other",
	"Search Label":"Search:",
	"Exclude Files":"Files to exclude (comma-separated):",
	"The following files are excluded from general setting":"The following files are excluded from general setting:",
	"Current Folder Tooltip": "Search in the closest parent folder of the target.",
	"Root Folder Tooltip": "Search in the root folder of the target.",
	"All Folders Tooltip": "Search in all folders of current workspace",
	"Other Folder Tooltip": "Search in a specified folder",
	"File Patterns Box Tooltip": "Search results are limited to the following file patterns",
	"Exclude Files Box Tooltip": "Search skips the following files, or all files of a folder of the name.",
	"To Replace Mode Tooltip": "Switch To Replace Mode",
	"To Search Mode Tooltip": "Switch To Search Mode"
});
